==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchRouteMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchRouteMatchBuilder extends EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl<EnvoyFilterRouteConfigurationMatchRouteMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatchRouteMatch,EnvoyFilterRouteConfigurationMatchRouteMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatchRouteMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatchRouteMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchRouteMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatchRouteMatch build() {
    EnvoyFilterRouteConfigurationMatchRouteMatch buildable = new EnvoyFilterRouteConfigurationMatchRouteMatch(fluent.getAction(),fluent.getName());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchRouteMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchRouteMatchBuilder extends EnvoyFilterRouteConfigurationMatchRouteMatchFluent<EnvoyFilterRouteConfigurationMatchRouteMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatchRouteMatch,EnvoyFilterRouteConfigurationMatchRouteMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatchRouteMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatchRouteMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchRouteMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatchRouteMatch());

    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withName(instance.getName());
      fluent.withAction(instance.getAction());
      fluent.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchBuilder(EnvoyFilterRouteConfigurationMatchRouteMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatchRouteMatch());

    if (instance != null) {
      this.withAction(instance.getAction());
      this.withName(instance.getName());
      this.withAction(instance.getAction());
      this.withName(instance.getName());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchRouteMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatchRouteMatch build() {
    EnvoyFilterRouteConfigurationMatchRouteMatch buildable = new EnvoyFilterRouteConfigurationMatchRouteMatch(fluent.getAction(),fluent.getName());
    return buildable;
  }
  
}
